/*
 * MacGate.h - Header for MacGate a LocalTalk to IP Gateway for Linux.
 *	Written By: Jay Schulist <Jay.Schulist@spacs.k12.wi.us>
 *	Copyright (C) 1997 Jay Schulist
 */

/* Device/system specific defines. */
#define LT_DEV          "lt0"           /* LocalTalk device to use. */
#define ETH_DEV         "eth0"          /* Ethernet device to use. */
#define LOOP_DEV        "lo"            /* LoopBack device to use. */
#define ARP		"/sbin/arp"	/* Full path to arp program. */

/*
 * There is no need to change anything below here.
 */

#include <sys/types.h>
#include <sys/param.h>
#include <sys/time.h>
#include <sys/ioctl.h>
#include <netatalk/endian.h>
#include <netatalk/at.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <syslog.h>
#include <signal.h>
#include <unistd.h>
#include <linux/socket.h>
#include <atalk/atp.h>
#include <atalk/nbp.h>
#include <linux/in.h>
#include <linux/fcntl.h>
#include <linux/if.h>
#include <linux/if_ether.h>
#include <linux/if_arp.h>
#include <arpa/inet.h>  	/* For inet_ntoa, inet_aton */
#include <netdb.h>
#include <ctype.h>

/* General defines. */
#define MAX(a, b)       ((a) > (b) ? (a) : (b))
#define MTU             	585     /* MTU. */
#define NODE_EXPIRE      	120      /* Route TTL in seconds. */

/* Ethernet specific defines. */
#define ETH_HDR_SIZE		14	/* Size of ethernet header. */
#define ETH_START_DATA		14	/* Where we can start putting data. */
#define ETH_START_TYPE  	12	/* Ethernet packet type field. */
#define SRC_ETH_IP_NUM		26	/* Where we pull SRC IP number from. */
#define DST_ETH_IP_NUM		30	/* Where we pull DST IP number from. */

/* ARP specific defines. */
#define ARP_DATA_SIZE		28	/* Amount of ARP reply data we send. */
#define ARP_HW_TYPE		14	/* ARP hw type field start. */
#define ARP_PROTO_TYPE		16	/* ARP proto type field start. */
#define ARP_HW_LEN		18	/* ARP hw len field start. */
#define ARP_PROTO_LEN		19	/* ARP proto len field start. */
#define ARP_OPER		20	/* ARP operation field start. */
#define ARP_SNDR_HW_ADDR	22	/* ARP sender hw addr field start. */
#define ARP_SNDR_IP_ADDR	28	/* ARP sender IP addr field start. */
#define ARP_TRGT_HW_ADDR	32	/* ARP target hw addr field start. */
#define ARP_TRGT_IP_ADDR	38	/* ARP target IP addr field start. */

/* Localtalk specific defines. */
#define MAC_IP_SOCKET   	72      /* Macintosh IP socket. */
#define DDP_IP_TYPE     	22      /* DDP IP code. */
#define LT_START_DATA     	8       /* Data field start. */
#define LT_SRC_IP_NUM		20	/* Where we pull LT Src IP from. */
#define LT_MAX_SIZE		603	/* Max LT packet size. */
#define LT_LLAP_HDRSIZE		3	/* Size of LLAP header. */
#define LT_LLAP_SRC_NODE        4       /* SRC node field start for 2.0.30. */
#define LT_LLAP_DEST_NODE	3	/* Rcv Dest node field for 2.0.30. */
#define LT_LLAP_TYPE		2	/* LLAP type field start. */

/* Short DDP header information. */
#define SDDP_HDRSIZE      	5       /* Size of SDDP header. */
#define SDDP_DDP_LENGTH   	3       /* SDDP length field start. */
#define SDDP_DEST_SOCK    	5       /* Dest. socket number field start. */
#define SDDP_SRC_SOCK     	6       /* Source socket number field start. */
#define SDDP_DDP_TYPE     	7       /* DDP type field start. */


/* Node Record for our IP to Net:Node map. */
struct ltip_list {
        struct ltip_list *next;		/* Next record. */
        struct at_addr sat_addr;        /* LocalTalk Net:Node pair. */
        __u32 ip;                       /* IP address of Macintosh. */
        long time;                      /* Time packet was recieved. */
};
